<div align="center">

  ![PMMA logo](https://github.com/PycraftDeveloper/PMMA/assets/81379254/2c4858b8-b50c-4f3b-95f3-d93fd1f0f19b)
</div>


# PMMA
Python Multi-Media API (PMMA) is a multi-purpose API designed to make working on multi-media projects easier and faster!
